[![CI](https://github.com/obeezzy/lpminimk3/actions/workflows/main.yml/badge.svg)](https://github.com/obeezzy/lpminimk3/actions/workflows/main.yml)

# lpminimk3
Python API for the [Novation Launchpad Mini MK3](https://novationmusic.com/en/launch/launchpad-mini) with an object-oriented approach.

## Goals
* Simple, object-oriented, intuitive design
* Ease of use for both scripting and "shelling"
* Access to all (or most) of the Launchpad Mini MK3 MIDI features

## Todo
- [x] Add unit tests.
- [x] Add CI.
- [x] Add documentation.
- [ ] Add CD.
- [ ] Add details to this README.
- [ ] Add examples.
- [ ] Add logging of MIDI messages.

## Future features
- [ ] Add DAW interface implementation.
- [ ] Add text scrolling.
- [ ] Add `Match`, for input filtering.
- [ ] Add `led_range()`, for group LED configurations.
- [ ] Add data-driven painting and animation.

## Notes
* Work in progress, so expect things to break!

## License
[MIT](https://choosealicense.com/licenses/mit/)
